@@ -1,9 +1,12 @@
 package Net::Irate::Track;
 
+use strict;
 use XML::TreeBuilder;
+use URI::Escape;
 
 sub new {
     my $pkg = shift || __PACKAGE__;
+
     my $self = { };
 
     $self->{track} = shift || XML::Element->new('track');
@@ -19,6 +22,17 @@ sub track {
     return $self->{track};
 }
 
+sub is_downloadable {
+    my $self = shift;
+
+    if($self->file eq undef &&
+       $self->state ne "broken") {
+	return 1;
+    } else {
+	return 0;
+    }
+}
+
 sub file {
     my $self = shift;
 
@@ -53,6 +67,26 @@ sub rating {
     return $self->track->attr("rating");
 }
 
+sub calc_filename {
+    my $self = shift;
+
+    my $url = $self->url;
+
+    my $t = uri_unescape($url);
+    $t =~ s/\s+/_/g;
+    $t =~ s/_+/_/g;
+    $t =~ s/[\'\"\,\!\(\)]//g;
+    $t =~ s/\&/and/g;
+    $t =~ s/_-_/-/g;
+    $t =~ s/-none-/-/ig;
+    $t =~ s/-unknown-/-/ig;
+    my @fn_parts = split(/\//, $t);
+    my $fn = pop(@fn_parts);
+
+    return $fn;
+}
+
+
 1;
 
 
